@@ -8,7 +8,7 @@
 
 import sqlalchemy as sa
 
-from .columns import create_columns, drop_columns
+from .columns import create_columns, drop_columns, set_not_null
 from .migrate_data import update_table_data
 from .trigger import create_triggers, drop_triggers
 
@@ -22,9 +22,10 @@ def upgrade(
     for table_name in tables:
         old_columns_to_migration_expression = table_name_to_old_columns_to_migration_expression.get(table_name, {})
         new_columns_to_migration_expression = table_name_to_new_columns_to_migration_expression.get(table_name, {})
-        create_columns(table_name, new_columns_to_migration_expression.keys())
+        create_columns(table_name, new_columns_to_migration_expression.keys(), force_nullable=True)
         create_triggers(table_name, old_columns_to_migration_expression, new_columns_to_migration_expression, revision)
         update_table_data(table_name, new_columns_to_migration_expression)
+        set_not_null(table_name, [col for col in old_columns_to_migration_expression if col.nullable is False])
 
 
 def finalize(
@@ -49,9 +50,10 @@ def undo_finalize(
         old_columns_to_migration_expression = table_name_to_old_columns_to_migration_expression.get(table_name, {})
         new_columns_to_migration_expression = table_name_to_new_columns_to_migration_expression.get(table_name, {})
 
-        create_columns(table_name, old_columns_to_migration_expression.keys())
+        create_columns(table_name, old_columns_to_migration_expression.keys(), force_nullable=True)
         create_triggers(table_name, old_columns_to_migration_expression, new_columns_to_migration_expression, revision)
         update_table_data(table_name, old_columns_to_migration_expression)
+        set_not_null(table_name, [col for col in old_columns_to_migration_expression if col.nullable is False])
 
 
 def downgrade(
